@@ -1,7 +1,13 @@
 from django.db import models
+
 from rest_framework import serializers
 
 
+# noinspection PyAbstractClass
+class EmptySerializer(serializers.Serializer):
+    pass
+
+
 # noinspection PyUnresolvedReferences
 class SerializerRequestMixin:
     @property
